# Pigreads

```{toctree}
:maxdepth: 2
:hidden:
```

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

```{eval-rst}
.. automodule:: pigreads

.. automodule:: pigreads._core

.. automodule:: pigreads._core_double
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
